# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
_static_36671184 = {u'a': u'1', u'c': u'3', u'b': u'2', }
_static_35828944 = {}
_static_35829584 = {u'class': u'None', }
_static_35889552 = {u'a': u'1', u'c': u'3', u'b': u'2', }
_static_35801168 = {u'a': u'1', u'c': u'3', u'b': u'2', }
_static_35707920 = {u'a': u'1', u'c': u'3', u'b': u'2', }
_static_35800848 = {u'a': u'1', u'c': u'3', u'b': u'2', }
_static_35830736 = {u'class': u"'hello'", }
_static_35890768 = {u'class': u'hello', }
_static_36668176 = {u'a': u'1', u'c': u'3', u'b': u'2', }
_static_35828624 = {}
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_39099424 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x222b4d0> name=None at 222b850> -> _value
    _value = _static_35828944
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36624936 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x222b390> name=None at 222b250> -> _value
    _value = _static_35828624
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36627376 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x222bbd0> name=None at 222b990> -> _value
    _value = _static_35830736
    econtext['attrs'] = _value

    # <span ... (3:4)
    # --------------------------------------------------------
    append(u'<span')
    _backup_default_36629176 = get('default', _marker)
    _value = None
    econtext['default'] = _value

    # <Expression u"'hello'" (3:32)> -> _attr_class
    try:
        _attr_class = 'hello'
    except:
        rcontext.setdefault('__error__', []).append((u"'hello'", 3, 32, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_class is None):
        pass
    else:
        if (_attr_class is False):
            _attr_class = None
        else:
            _tt = type(_attr_class)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_class = unicode(_attr_class)
            else:
                try:
                    if (_tt is str):
                        _attr_class = decode(_attr_class)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_class = _attr_class.__html__
                            except:
                                _attr_class = convert(_attr_class)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_class = _attr_class()
                else:
                    if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                        if ('&' in _attr_class):
                            if (';' in _attr_class):
                                _attr_class = re_amp.sub('&amp;', _attr_class)
                            else:
                                _attr_class = _attr_class.replace('&', '&amp;')
                        if ('<' in _attr_class):
                            _attr_class = _attr_class.replace('<', '&lt;')
                        if ('>' in _attr_class):
                            _attr_class = _attr_class.replace('>', '&gt;')
                        if ('"' in _attr_class):
                            _attr_class = _attr_class.replace('"', '&#34;')
    if (_attr_class is not None):
        append((u' class="%s"' % _attr_class))
    if (_backup_default_36629176 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36629176
    append(u' />')
    if (_backup_attrs_36627376 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36627376
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36724032 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x222b750> name=None at 222bf90> -> _value
    _value = _static_35829584
    econtext['attrs'] = _value

    # <span ... (4:4)
    # --------------------------------------------------------
    append(u'<span')
    _backup_default_36724464 = get('default', _marker)
    _value = None
    econtext['default'] = _value

    # <Expression u'None' (4:32)> -> _attr_class
    try:
        _attr_class = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 4, 32, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_class is None):
        pass
    else:
        if (_attr_class is False):
            _attr_class = None
        else:
            _tt = type(_attr_class)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_class = unicode(_attr_class)
            else:
                try:
                    if (_tt is str):
                        _attr_class = decode(_attr_class)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_class = _attr_class.__html__
                            except:
                                _attr_class = convert(_attr_class)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_class = _attr_class()
                else:
                    if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                        if ('&' in _attr_class):
                            if (';' in _attr_class):
                                _attr_class = re_amp.sub('&amp;', _attr_class)
                            else:
                                _attr_class = _attr_class.replace('&', '&amp;')
                        if ('<' in _attr_class):
                            _attr_class = _attr_class.replace('<', '&lt;')
                        if ('>' in _attr_class):
                            _attr_class = _attr_class.replace('>', '&gt;')
                        if ('"' in _attr_class):
                            _attr_class = _attr_class.replace('"', '&#34;')
    if (_attr_class is not None):
        append((u' class="%s"' % _attr_class))
    if (_backup_default_36724464 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36724464
    append(u' />')
    if (_backup_attrs_36724032 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36724032
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36721872 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2224710> name=None at 2224090> -> _value
    _value = _static_35800848
    econtext['attrs'] = _value

    # <span ... (5:4)
    # --------------------------------------------------------
    append(u'<span')
    _backup_default_36721584 = get('default', _marker)
    _value = u'1'
    econtext['default'] = _value

    # <Expression u'None' (5:46)> -> _attr_a
    try:
        _attr_a = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 5, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_a is None):
        pass
    else:
        if (_attr_a is False):
            _attr_a = None
        else:
            _tt = type(_attr_a)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_a = unicode(_attr_a)
            else:
                try:
                    if (_tt is str):
                        _attr_a = decode(_attr_a)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_a = _attr_a.__html__
                            except:
                                _attr_a = convert(_attr_a)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_a = _attr_a()
                else:
                    if ((_attr_a is not None) and (re_needs_escape(_attr_a) is not None)):
                        if ('&' in _attr_a):
                            if (';' in _attr_a):
                                _attr_a = re_amp.sub('&amp;', _attr_a)
                            else:
                                _attr_a = _attr_a.replace('&', '&amp;')
                        if ('<' in _attr_a):
                            _attr_a = _attr_a.replace('<', '&lt;')
                        if ('>' in _attr_a):
                            _attr_a = _attr_a.replace('>', '&gt;')
                        if (u'"' in _attr_a):
                            _attr_a = _attr_a.replace(u'"', '&#34;')
    if (_attr_a is not None):
        append((u' a="%s"' % _attr_a))
    if (_backup_default_36721584 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36721584
    _attr_b = u'2'
    if (_attr_b is not None):
        append((u' b="%s"' % _attr_b))
    _attr_c = u'3'
    if (_attr_c is not None):
        append((u' c="%s"' % _attr_c))
    append(u' />')
    if (_backup_attrs_36721872 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36721872
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36722376 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2224850> name=None at 2224050> -> _value
    _value = _static_35801168
    econtext['attrs'] = _value

    # <span ... (6:4)
    # --------------------------------------------------------
    append(u'<span')
    _attr_a = u'1'
    if (_attr_a is not None):
        append((u' a="%s"' % _attr_a))
    _backup_default_36722520 = get('default', _marker)
    _value = u'2'
    econtext['default'] = _value

    # <Expression u'None' (6:46)> -> _attr_b
    try:
        _attr_b = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 6, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_b is None):
        pass
    else:
        if (_attr_b is False):
            _attr_b = None
        else:
            _tt = type(_attr_b)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_b = unicode(_attr_b)
            else:
                try:
                    if (_tt is str):
                        _attr_b = decode(_attr_b)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_b = _attr_b.__html__
                            except:
                                _attr_b = convert(_attr_b)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_b = _attr_b()
                else:
                    if ((_attr_b is not None) and (re_needs_escape(_attr_b) is not None)):
                        if ('&' in _attr_b):
                            if (';' in _attr_b):
                                _attr_b = re_amp.sub('&amp;', _attr_b)
                            else:
                                _attr_b = _attr_b.replace('&', '&amp;')
                        if ('<' in _attr_b):
                            _attr_b = _attr_b.replace('<', '&lt;')
                        if ('>' in _attr_b):
                            _attr_b = _attr_b.replace('>', '&gt;')
                        if (u'"' in _attr_b):
                            _attr_b = _attr_b.replace(u'"', '&#34;')
    if (_attr_b is not None):
        append((u' b="%s"' % _attr_b))
    if (_backup_default_36722520 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36722520
    _attr_c = u'3'
    if (_attr_c is not None):
        append((u' c="%s"' % _attr_c))
    append(u' />')
    if (_backup_attrs_36722376 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36722376
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36723312 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8310> name=None at 22f8650> -> _value
    _value = _static_36668176
    econtext['attrs'] = _value

    # <span ... (7:4)
    # --------------------------------------------------------
    append(u'<span')
    _attr_a = u'1'
    if (_attr_a is not None):
        append((u' a="%s"' % _attr_a))
    _attr_b = u'2'
    if (_attr_b is not None):
        append((u' b="%s"' % _attr_b))
    _backup_default_36723240 = get('default', _marker)
    _value = u'3'
    econtext['default'] = _value

    # <Expression u'None' (7:46)> -> _attr_c
    try:
        _attr_c = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 7, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_c is None):
        pass
    else:
        if (_attr_c is False):
            _attr_c = None
        else:
            _tt = type(_attr_c)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_c = unicode(_attr_c)
            else:
                try:
                    if (_tt is str):
                        _attr_c = decode(_attr_c)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_c = _attr_c.__html__
                            except:
                                _attr_c = convert(_attr_c)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_c = _attr_c()
                else:
                    if ((_attr_c is not None) and (re_needs_escape(_attr_c) is not None)):
                        if ('&' in _attr_c):
                            if (';' in _attr_c):
                                _attr_c = re_amp.sub('&amp;', _attr_c)
                            else:
                                _attr_c = _attr_c.replace('&', '&amp;')
                        if ('<' in _attr_c):
                            _attr_c = _attr_c.replace('<', '&lt;')
                        if ('>' in _attr_c):
                            _attr_c = _attr_c.replace('>', '&gt;')
                        if (u'"' in _attr_c):
                            _attr_c = _attr_c.replace(u'"', '&#34;')
    if (_attr_c is not None):
        append((u' c="%s"' % _attr_c))
    if (_backup_default_36723240 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36723240
    append(u' />')
    if (_backup_attrs_36723312 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36723312
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36724248 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8ed0> name=None at 22f8f90> -> _value
    _value = _static_36671184
    econtext['attrs'] = _value

    # <span ... (8:4)
    # --------------------------------------------------------
    append(u'<span')
    _attr_a = u'1'
    if (_attr_a is not None):
        append((u' a="%s"' % _attr_a))
    _backup_default_36723384 = get('default', _marker)
    _value = u'2'
    econtext['default'] = _value

    # <Expression u'None' (8:46)> -> _attr_b
    try:
        _attr_b = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 8, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_b is None):
        pass
    else:
        if (_attr_b is False):
            _attr_b = None
        else:
            _tt = type(_attr_b)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_b = unicode(_attr_b)
            else:
                try:
                    if (_tt is str):
                        _attr_b = decode(_attr_b)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_b = _attr_b.__html__
                            except:
                                _attr_b = convert(_attr_b)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_b = _attr_b()
                else:
                    if ((_attr_b is not None) and (re_needs_escape(_attr_b) is not None)):
                        if ('&' in _attr_b):
                            if (';' in _attr_b):
                                _attr_b = re_amp.sub('&amp;', _attr_b)
                            else:
                                _attr_b = _attr_b.replace('&', '&amp;')
                        if ('<' in _attr_b):
                            _attr_b = _attr_b.replace('<', '&lt;')
                        if ('>' in _attr_b):
                            _attr_b = _attr_b.replace('>', '&gt;')
                        if (u'"' in _attr_b):
                            _attr_b = _attr_b.replace(u'"', '&#34;')
    if (_attr_b is not None):
        append((u' b="%s"' % _attr_b))
    if (_backup_default_36723384 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36723384
    _backup_default_36724680 = get('default', _marker)
    _value = u'3'
    econtext['default'] = _value

    # <Expression u'None' (8:53)> -> _attr_c
    try:
        _attr_c = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 8, 53, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_c is None):
        pass
    else:
        if (_attr_c is False):
            _attr_c = None
        else:
            _tt = type(_attr_c)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_c = unicode(_attr_c)
            else:
                try:
                    if (_tt is str):
                        _attr_c = decode(_attr_c)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_c = _attr_c.__html__
                            except:
                                _attr_c = convert(_attr_c)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_c = _attr_c()
                else:
                    if ((_attr_c is not None) and (re_needs_escape(_attr_c) is not None)):
                        if ('&' in _attr_c):
                            if (';' in _attr_c):
                                _attr_c = re_amp.sub('&amp;', _attr_c)
                            else:
                                _attr_c = _attr_c.replace('&', '&amp;')
                        if ('<' in _attr_c):
                            _attr_c = _attr_c.replace('<', '&lt;')
                        if ('>' in _attr_c):
                            _attr_c = _attr_c.replace('>', '&gt;')
                        if (u'"' in _attr_c):
                            _attr_c = _attr_c.replace(u'"', '&#34;')
    if (_attr_c is not None):
        append((u' c="%s"' % _attr_c))
    if (_backup_default_36724680 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36724680
    append(u' />')
    if (_backup_attrs_36724248 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36724248
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_38641744 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x220dc10> name=None at 220ddd0> -> _value
    _value = _static_35707920
    econtext['attrs'] = _value

    # <span ... (9:4)
    # --------------------------------------------------------
    append(u'<span')
    _attr_a = u'1'
    if (_attr_a is not None):
        append((u' a="%s"' % _attr_a))
    _backup_default_38642032 = get('default', _marker)
    _value = u'2'
    econtext['default'] = _value

    # <Expression u'string:;' (9:46)> -> _attr_b
    try:
        _attr_b = u';'
    except:
        rcontext.setdefault('__error__', []).append((u'string:;', 9, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_b is None):
        pass
    else:
        if (_attr_b is False):
            _attr_b = None
        else:
            _tt = type(_attr_b)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_b = unicode(_attr_b)
            else:
                try:
                    if (_tt is str):
                        _attr_b = decode(_attr_b)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_b = _attr_b.__html__
                            except:
                                _attr_b = convert(_attr_b)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_b = _attr_b()
                else:
                    if ((_attr_b is not None) and (re_needs_escape(_attr_b) is not None)):
                        if ('&' in _attr_b):
                            if (';' in _attr_b):
                                _attr_b = re_amp.sub('&amp;', _attr_b)
                            else:
                                _attr_b = _attr_b.replace('&', '&amp;')
                        if ('<' in _attr_b):
                            _attr_b = _attr_b.replace('<', '&lt;')
                        if ('>' in _attr_b):
                            _attr_b = _attr_b.replace('>', '&gt;')
                        if (u'"' in _attr_b):
                            _attr_b = _attr_b.replace(u'"', '&#34;')
    if (_attr_b is not None):
        append((u' b="%s"' % _attr_b))
    if (_backup_default_38642032 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38642032
    _attr_c = u'3'
    if (_attr_c is not None):
        append((u' c="%s"' % _attr_c))
    append(u' />')
    if (_backup_attrs_38641744 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38641744
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36721224 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x223a190> name=None at 223a1d0> -> _value
    _value = _static_35889552
    econtext['attrs'] = _value

    # <span ... (10:4)
    # --------------------------------------------------------
    append(u'<span')
    _attr_a = u'1'
    if (_attr_a is not None):
        append((u' a="%s"' % _attr_a))
    _backup_default_36721080 = get('default', _marker)
    _value = u'2'
    econtext['default'] = _value

    # <Expression u'string:&amp;' (10:46)> -> _attr_b
    try:
        _attr_b = u'&amp;'
    except:
        rcontext.setdefault('__error__', []).append((u'string:&amp;', 10, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_b is None):
        pass
    else:
        if (_attr_b is False):
            _attr_b = None
        else:
            _tt = type(_attr_b)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_b = unicode(_attr_b)
            else:
                try:
                    if (_tt is str):
                        _attr_b = decode(_attr_b)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_b = _attr_b.__html__
                            except:
                                _attr_b = convert(_attr_b)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_b = _attr_b()
                else:
                    if ((_attr_b is not None) and (re_needs_escape(_attr_b) is not None)):
                        if ('&' in _attr_b):
                            if (';' in _attr_b):
                                _attr_b = re_amp.sub('&amp;', _attr_b)
                            else:
                                _attr_b = _attr_b.replace('&', '&amp;')
                        if ('<' in _attr_b):
                            _attr_b = _attr_b.replace('<', '&lt;')
                        if ('>' in _attr_b):
                            _attr_b = _attr_b.replace('>', '&gt;')
                        if (u'"' in _attr_b):
                            _attr_b = _attr_b.replace(u'"', '&#34;')
    if (_attr_b is not None):
        append((u' b="%s"' % _attr_b))
    if (_backup_default_36721080 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36721080
    _attr_c = u'3'
    if (_attr_c is not None):
        append((u' c="%s"' % _attr_c))
    append(u' />')
    if (_backup_attrs_36721224 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36721224
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_38642176 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x223a650> name=None at 223a250> -> _value
    _value = _static_35890768
    econtext['attrs'] = _value

    # <span ... (11:4)
    # --------------------------------------------------------
    append(u'<span')
    _backup_default_38642104 = get('default', _marker)
    _value = u'hello'
    econtext['default'] = _value

    # <Expression u"'goodbye'" (11:46)> -> _attr_class
    try:
        _attr_class = 'goodbye'
    except:
        rcontext.setdefault('__error__', []).append((u"'goodbye'", 11, 46, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_class is None):
        pass
    else:
        if (_attr_class is False):
            _attr_class = None
        else:
            _tt = type(_attr_class)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_class = unicode(_attr_class)
            else:
                try:
                    if (_tt is str):
                        _attr_class = decode(_attr_class)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_class = _attr_class.__html__
                            except:
                                _attr_class = convert(_attr_class)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_class = _attr_class()
                else:
                    if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                        if ('&' in _attr_class):
                            if (';' in _attr_class):
                                _attr_class = re_amp.sub('&amp;', _attr_class)
                            else:
                                _attr_class = _attr_class.replace('&', '&amp;')
                        if ('<' in _attr_class):
                            _attr_class = _attr_class.replace('<', '&lt;')
                        if ('>' in _attr_class):
                            _attr_class = _attr_class.replace('>', '&gt;')
                        if (u'"' in _attr_class):
                            _attr_class = _attr_class.replace(u'"', '&#34;')
    if (_attr_class is not None):
        append((u' class="%s"' % _attr_class))
    if (_backup_default_38642104 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38642104
    append(u' />')
    if (_backup_attrs_38642176 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38642176
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_36624936 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36624936
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_39099424 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39099424
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')

    # <Expression u"load('032-master-template.pt').macros['main']" (1:23)> -> _macro
    try:
        _macro = getitem('load')('032-master-template.pt').macros['main']
    except:
        rcontext.setdefault('__error__', []).append((u"load('032-master-template.pt').macros['main']", 1, 23, '<string>', _sys.exc_info()[1], ))
        raise

    _macro.include(stream, econtext.copy(), rcontext)
    econtext.update(rcontext)
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
from chameleon.py26 import lookup_attr as _lookup_attr
import sys as _sys
pass
_static_38933456 = {}
_static_39103952 = {u'class': u"repeat['i'].even+repeat['i'].odd", }
_static_38935056 = {}
_static_39102992 = {}
_static_38908624 = {u'xmlns': u'http://www.w3.org/1999/xhtml', }
_static_39102672 = {}
_static_37140880 = {}
_static_38936208 = {}
_static_38934416 = {}
_static_37140112 = {u'name': u'${i}-${repeat.i.index}', u'class': u"repeat['i'].even()+repeat['i'].odd()", }
_static_38935312 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_38631760 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x251b2d0> name=None at 251b610> -> _value
    _value = _static_38908624
    econtext['attrs'] = _value

    # <div ... (1:0)
    # --------------------------------------------------------
    append(u'<div')
    _attr_xmlns = u'http://www.w3.org/1999/xhtml'
    if (_attr_xmlns is not None):
        append((u' xmlns="%s"' % _attr_xmlns))
    append(u'>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39790784 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x236b990> name=None at 236b890> -> _value
    _value = _static_37140880
    econtext['attrs'] = _value

    # <ul ... (3:2)
    # --------------------------------------------------------
    append(u'<ul>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_i_35883472 = get('i', _marker)

    # <Expression u'range(3)' (4:112)> -> _iterator
    try:
        _iterator = get('range', range)(3)
    except:
        rcontext.setdefault('__error__', []).append((u'range(3)', 4, 112, '<string>', _sys.exc_info()[1], ))
        raise

    (_iterator, __index_39101072, ) = getitem('repeat')(u'i', _iterator)
    econtext['i'] = None
    for _item in _iterator:
        econtext['i'] = _item
        _backup_attrs_35757664 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x236b690> name=None at 236b490> -> _value
        _value = _static_37140112
        econtext['attrs'] = _value

        # <li ... (4:4)
        # --------------------------------------------------------
        append(u'<li')
        _backup_default_35754928 = get('default', _marker)
        _value = u'${i}-${repeat.i.index}'
        econtext['default'] = _value

        # <Interpolation value=u'${i}-${repeat.i.index}' escape=True at 236b2d0> -> _attr_name

        # <Expression u'i' (4:76)> -> _attr_name
        try:
            _attr_name = getitem('i')
        except:
            rcontext.setdefault('__error__', []).append((u'i', 4, 76, '<string>', _sys.exc_info()[1], ))
            raise


        # <Expression u'repeat.i.index' (4:81)> -> _attr_name_181
        try:
            _attr_name_181 = _lookup_attr(getitem('repeat'), 'i').index
        except:
            rcontext.setdefault('__error__', []).append((u'repeat.i.index', 4, 81, '<string>', _sys.exc_info()[1], ))
            raise

        _attr_name = ('%s%s%s' % ((_attr_name if (_attr_name is not None) else ''), (u'-' if (u'-' is not None) else ''), (_attr_name_181 if (_attr_name_181 is not None) else ''), ))
        if (_attr_name is None):
            pass
        else:
            if (_attr_name is False):
                _attr_name = None
            else:
                _tt = type(_attr_name)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _attr_name = unicode(_attr_name)
                else:
                    try:
                        if (_tt is str):
                            _attr_name = decode(_attr_name)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _attr_name = _attr_name.__html__
                                except:
                                    _attr_name = convert(_attr_name)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _attr_name = _attr_name()
                    else:
                        if ((_attr_name is not None) and (re_needs_escape(_attr_name) is not None)):
                            if ('&' in _attr_name):
                                if (';' in _attr_name):
                                    _attr_name = re_amp.sub('&amp;', _attr_name)
                                else:
                                    _attr_name = _attr_name.replace('&', '&amp;')
                            if ('<' in _attr_name):
                                _attr_name = _attr_name.replace('<', '&lt;')
                            if ('>' in _attr_name):
                                _attr_name = _attr_name.replace('>', '&gt;')
                            if (u'"' in _attr_name):
                                _attr_name = _attr_name.replace(u'"', '&#34;')
        if (_attr_name is not None):
            append((u' name="%s"' % _attr_name))
        if (_backup_default_35754928 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_35754928
        _backup_default_35754064 = get('default', _marker)
        _value = None
        econtext['default'] = _value

        # <Expression u"repeat['i'].even()+repeat['i'].odd()" (4:30)> -> _attr_class
        try:
            _attr_class = (getitem('repeat')['i'].even() + getitem('repeat')['i'].odd())
        except:
            rcontext.setdefault('__error__', []).append((u"repeat['i'].even()+repeat['i'].odd()", 4, 30, '<string>', _sys.exc_info()[1], ))
            raise

        if (_attr_class is None):
            pass
        else:
            if (_attr_class is False):
                _attr_class = None
            else:
                _tt = type(_attr_class)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _attr_class = unicode(_attr_class)
                else:
                    try:
                        if (_tt is str):
                            _attr_class = decode(_attr_class)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _attr_class = _attr_class.__html__
                                except:
                                    _attr_class = convert(_attr_class)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _attr_class = _attr_class()
                    else:
                        if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                            if ('&' in _attr_class):
                                if (';' in _attr_class):
                                    _attr_class = re_amp.sub('&amp;', _attr_class)
                                else:
                                    _attr_class = _attr_class.replace('&', '&amp;')
                            if ('<' in _attr_class):
                                _attr_class = _attr_class.replace('<', '&lt;')
                            if ('>' in _attr_class):
                                _attr_class = _attr_class.replace('>', '&gt;')
                            if ('"' in _attr_class):
                                _attr_class = _attr_class.replace('"', '&#34;')
        if (_attr_class is not None):
            append((u' class="%s"' % _attr_class))
        if (_backup_default_35754064 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_35754064
        append(u'>')
        _backup_default_35756584 = get('default', _marker)

        # <Marker name='default' at 254aed0> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'i' (4:141)> -> _cache_39102928
        try:
            _cache_39102928 = getitem('i')
        except:
            rcontext.setdefault('__error__', []).append((u'i', 4, 141, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'i' (4:141)> value=<Marker name='default' at 254ab90> at 254aa50> -> _condition
        _expression = _cache_39102928

        # <Marker name='default' at 254ab90> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            _backup_attrs_35754712 = get('attrs', _marker)

            # <Static value=<_ast.Dict object at 0x254a8d0> name=None at 254a110> -> _value
            _value = _static_39102672
            econtext['attrs'] = _value

            # <span ... (4:122)
            # --------------------------------------------------------
            append(u'<span />')
            if (_backup_attrs_35754712 is _marker):
                del econtext['attrs']
            else:
                econtext['attrs'] = _backup_attrs_35754712
        else:
            _content = _cache_39102928
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_35756584 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_35756584
        append(u'</li>')
        if (_backup_attrs_35757664 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_35757664
        __index_39101072 -= 1
        if (__index_39101072 > 0):
            append('\n    ')
    if (_backup_i_35883472 is _marker):
        del econtext['i']
    else:
        econtext['i'] = _backup_i_35883472
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</ul>')
    if (_backup_attrs_39790784 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39790784
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35754496 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x254aa10> name=None at 254ac90> -> _value
    _value = _static_39102992
    econtext['attrs'] = _value

    # <ul ... (6:2)
    # --------------------------------------------------------
    append(u'<ul>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_i_40028112 = get('i', _marker)

    # <Expression u'range(3)' (8:22)> -> _iterator
    try:
        _iterator = get('range', range)(3)
    except:
        rcontext.setdefault('__error__', []).append((u'range(3)', 8, 22, '<string>', _sys.exc_info()[1], ))
        raise

    (_iterator, __index_38403088, ) = getitem('repeat')(u'i', _iterator)
    econtext['i'] = None
    for _item in _iterator:
        econtext['i'] = _item
        _backup_attrs_35756368 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x254add0> name=None at 254aad0> -> _value
        _value = _static_39103952
        econtext['attrs'] = _value

        # <li ... (7:4)
        # --------------------------------------------------------
        append(u'<li')
        _backup_default_35757088 = get('default', _marker)
        _value = None
        econtext['default'] = _value

        # <Expression u"repeat['i'].even+repeat['i'].odd" (7:30)> -> _attr_class
        try:
            _attr_class = (getitem('repeat')['i'].even + getitem('repeat')['i'].odd)
        except:
            rcontext.setdefault('__error__', []).append((u"repeat['i'].even+repeat['i'].odd", 7, 30, '<string>', _sys.exc_info()[1], ))
            raise

        if (_attr_class is None):
            pass
        else:
            if (_attr_class is False):
                _attr_class = None
            else:
                _tt = type(_attr_class)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _attr_class = unicode(_attr_class)
                else:
                    try:
                        if (_tt is str):
                            _attr_class = decode(_attr_class)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _attr_class = _attr_class.__html__
                                except:
                                    _attr_class = convert(_attr_class)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _attr_class = _attr_class()
                    else:
                        if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                            if ('&' in _attr_class):
                                if (';' in _attr_class):
                                    _attr_class = re_amp.sub('&amp;', _attr_class)
                                else:
                                    _attr_class = _attr_class.replace('&', '&amp;')
                            if ('<' in _attr_class):
                                _attr_class = _attr_class.replace('<', '&lt;')
                            if ('>' in _attr_class):
                                _attr_class = _attr_class.replace('>', '&gt;')
                            if ('"' in _attr_class):
                                _attr_class = _attr_class.replace('"', '&#34;')
        if (_attr_class is not None):
            append((u' class="%s"' % _attr_class))
        if (_backup_default_35757088 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_35757088
        append(u'>')
        _backup_default_36681632 = get('default', _marker)

        # <Marker name='default' at 2521fd0> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'i' (8:51)> -> _cache_38935952
        try:
            _cache_38935952 = getitem('i')
        except:
            rcontext.setdefault('__error__', []).append((u'i', 8, 51, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'i' (8:51)> value=<Marker name='default' at 2521950> at 2521d10> -> _condition
        _expression = _cache_38935952

        # <Marker name='default' at 2521950> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            _backup_attrs_36679832 = get('attrs', _marker)

            # <Static value=<_ast.Dict object at 0x2521e90> name=None at 249f050> -> _value
            _value = _static_38936208
            econtext['attrs'] = _value

            # <span ... (8:32)
            # --------------------------------------------------------
            append(u'<span />')
            if (_backup_attrs_36679832 is _marker):
                del econtext['attrs']
            else:
                econtext['attrs'] = _backup_attrs_36679832
        else:
            _content = _cache_38935952
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_36681632 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_36681632
        append(u'</li>')
        if (_backup_attrs_35756368 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_35756368
        __index_38403088 -= 1
        if (__index_38403088 > 0):
            append('\n    ')
    if (_backup_i_40028112 is _marker):
        del econtext['i']
    else:
        econtext['i'] = _backup_i_40028112
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</ul>')
    if (_backup_attrs_35754496 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35754496
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36680552 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2521b10> name=None at 2521f90> -> _value
    _value = _static_38935312
    econtext['attrs'] = _value

    # <ul ... (10:2)
    # --------------------------------------------------------
    append(u'<ul>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_i_35203664 = get('i', _marker)

    # <Expression u'range(3)' (11:22)> -> _iterator
    try:
        _iterator = get('range', range)(3)
    except:
        rcontext.setdefault('__error__', []).append((u'range(3)', 11, 22, '<string>', _sys.exc_info()[1], ))
        raise

    (_iterator, __index_38934352, ) = getitem('repeat')(u'i', _iterator)
    econtext['i'] = None
    for _item in _iterator:
        econtext['i'] = _item
        _backup_attrs_36746592 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2521a10> name=None at 2521550> -> _value
        _value = _static_38935056
        econtext['attrs'] = _value

        # <li ... (11:4)
        # --------------------------------------------------------
        append(u'<li>')

        # <Expression u"repeat['i'].even" (11:53)> -> _condition
        try:
            _condition = getitem('repeat')['i'].even
        except:
            rcontext.setdefault('__error__', []).append((u"repeat['i'].even", 11, 53, '<string>', _sys.exc_info()[1], ))
            raise

        if _condition:
            _backup_default_39092096 = get('default', _marker)

            # <Marker name='default' at 2521150> -> _value
            _value = _marker_default
            econtext['default'] = _value

            # <Expression u"repeat['i'].even" (11:84)> -> _cache_38932752
            try:
                _cache_38932752 = getitem('repeat')['i'].even
            except:
                rcontext.setdefault('__error__', []).append((u"repeat['i'].even", 11, 84, '<string>', _sys.exc_info()[1], ))
                raise


            # <Identity expression=<Expression u"repeat['i'].even" (11:84)> value=<Marker name='default' at 2521390> at 25214d0> -> _condition
            _expression = _cache_38932752

            # <Marker name='default' at 2521390> -> _value
            _value = _marker_default
            _condition = (_expression is _value)
            if _condition:
                _backup_attrs_39088424 = get('attrs', _marker)

                # <Static value=<_ast.Dict object at 0x2521790> name=None at 25217d0> -> _value
                _value = _static_38934416
                econtext['attrs'] = _value

                # <span ... (11:32)
                # --------------------------------------------------------
                append(u'<span />')
                if (_backup_attrs_39088424 is _marker):
                    del econtext['attrs']
                else:
                    econtext['attrs'] = _backup_attrs_39088424
            else:
                _content = _cache_38932752
                if (_content is None):
                    pass
                else:
                    if (_content is False):
                        _content = None
                    else:
                        _tt = type(_content)
                        if ((_tt is int) or (_tt is float) or (_tt is long)):
                            _content = unicode(_content)
                        else:
                            try:
                                if (_tt is str):
                                    _content = decode(_content)
                                else:
                                    if (_tt is not unicode):
                                        try:
                                            _content = _content.__html__
                                        except:
                                            _content = convert(_content)
                                        else:
                                            raise RuntimeError
                            except RuntimeError:
                                _content = _content()
                            else:
                                if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                    if ('&' in _content):
                                        if (';' in _content):
                                            _content = re_amp.sub('&amp;', _content)
                                        else:
                                            _content = _content.replace('&', '&amp;')
                                    if ('<' in _content):
                                        _content = _content.replace('<', '&lt;')
                                    if ('>' in _content):
                                        _content = _content.replace('>', '&gt;')
                                    if ('\x00' in _content):
                                        _content = _content.replace('\x00', '&#34;')
                if (_content is not None):
                    append(_content)
            if (_backup_default_39092096 is _marker):
                del econtext['default']
            else:
                econtext['default'] = _backup_default_39092096

        # <Expression u"repeat['i'].odd" (11:125)> -> _condition
        try:
            _condition = getitem('repeat')['i'].odd
        except:
            rcontext.setdefault('__error__', []).append((u"repeat['i'].odd", 11, 125, '<string>', _sys.exc_info()[1], ))
            raise

        if _condition:
            _backup_default_39089000 = get('default', _marker)

            # <Marker name='default' at 262c590> -> _value
            _value = _marker_default
            econtext['default'] = _value

            # <Expression u"repeat['i'].odd" (11:155)> -> _cache_38936400
            try:
                _cache_38936400 = getitem('repeat')['i'].odd
            except:
                rcontext.setdefault('__error__', []).append((u"repeat['i'].odd", 11, 155, '<string>', _sys.exc_info()[1], ))
                raise


            # <Identity expression=<Expression u"repeat['i'].odd" (11:155)> value=<Marker name='default' at 262c0d0> at 262c850> -> _condition
            _expression = _cache_38936400

            # <Marker name='default' at 262c0d0> -> _value
            _value = _marker_default
            _condition = (_expression is _value)
            if _condition:
                _backup_attrs_39091592 = get('attrs', _marker)

                # <Static value=<_ast.Dict object at 0x25213d0> name=None at 2521050> -> _value
                _value = _static_38933456
                econtext['attrs'] = _value

                # <span ... (11:104)
                # --------------------------------------------------------
                append(u'<span />')
                if (_backup_attrs_39091592 is _marker):
                    del econtext['attrs']
                else:
                    econtext['attrs'] = _backup_attrs_39091592
            else:
                _content = _cache_38936400
                if (_content is None):
                    pass
                else:
                    if (_content is False):
                        _content = None
                    else:
                        _tt = type(_content)
                        if ((_tt is int) or (_tt is float) or (_tt is long)):
                            _content = unicode(_content)
                        else:
                            try:
                                if (_tt is str):
                                    _content = decode(_content)
                                else:
                                    if (_tt is not unicode):
                                        try:
                                            _content = _content.__html__
                                        except:
                                            _content = convert(_content)
                                        else:
                                            raise RuntimeError
                            except RuntimeError:
                                _content = _content()
                            else:
                                if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                    if ('&' in _content):
                                        if (';' in _content):
                                            _content = re_amp.sub('&amp;', _content)
                                        else:
                                            _content = _content.replace('&', '&amp;')
                                    if ('<' in _content):
                                        _content = _content.replace('<', '&lt;')
                                    if ('>' in _content):
                                        _content = _content.replace('>', '&gt;')
                                    if ('\x00' in _content):
                                        _content = _content.replace('\x00', '&#34;')
                if (_content is not None):
                    append(_content)
            if (_backup_default_39089000 is _marker):
                del econtext['default']
            else:
                econtext['default'] = _backup_default_39089000
        append(u'</li>')
        if (_backup_attrs_36746592 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_36746592
        __index_38934352 -= 1
        if (__index_38934352 > 0):
            append('\n    ')
    if (_backup_i_35203664 is _marker):
        del econtext['i']
    else:
        econtext['i'] = _backup_i_35203664
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</ul>')
    if (_backup_attrs_36680552 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36680552
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</div>')
    if (_backup_attrs_38631760 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38631760
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
_static_38461840 = {}
_static_38461520 = {}
_static_38576336 = {u'class': u"${'omitted'}", }
_static_38578640 = {u'class': u'omitted', }
_static_38464592 = {}
_static_38400400 = {}
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_38457568 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24ae190> name=None at 24aebd0> -> _value
    _value = _static_38461840
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36649800 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24aec50> name=None at 24ae510> -> _value
    _value = _static_38464592
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _content_139955154988272 = u'Hello world!'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _content_139955154988272 = u'1\n      Hello world!\n   2'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _content_139955154988272 = u'3\n   4'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)

    # <Negate value=<Expression u'True' (7:23)> at 249f690> -> _cache_38401680

    # <Expression u'True' (7:23)> -> _cache_38401680
    try:
        _cache_38401680 = True
    except:
        rcontext.setdefault('__error__', []).append((u'True', 7, 23, '<string>', _sys.exc_info()[1], ))
        raise

    _cache_38401680 = not _cache_38401680
    _backup_attrs_38602080 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24ae050> name=None at 24ae210> -> _value
    _value = _static_38461520
    econtext['attrs'] = _value
    _condition = _cache_38401680
    if _condition:

        # <div ... (7:4)
        # --------------------------------------------------------
        append(u'<div>')
    _content_139955154988272 = u'Hello world!'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _condition = _cache_38401680
    if _condition:
        append(u'</div>')
    if (_backup_attrs_38602080 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38602080
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)

    # <Negate value=<Expression u'False' (8:23)> at 249f750> -> _cache_38401872

    # <Expression u'False' (8:23)> -> _cache_38401872
    try:
        _cache_38401872 = False
    except:
        rcontext.setdefault('__error__', []).append((u'False', 8, 23, '<string>', _sys.exc_info()[1], ))
        raise

    _cache_38401872 = not _cache_38401872
    _backup_attrs_37106464 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x249f190> name=None at 249f950> -> _value
    _value = _static_38400400
    econtext['attrs'] = _value
    _condition = _cache_38401872
    if _condition:

        # <div ... (8:4)
        # --------------------------------------------------------
        append(u'<div>')
    _content_139955154988272 = u'Hello world!'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _condition = _cache_38401872
    if _condition:
        append(u'</div>')
    if (_backup_attrs_37106464 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_37106464
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)

    # <Negate value=<Expression u'True' (9:39)> at 24cae10> -> _cache_38579728

    # <Expression u'True' (9:39)> -> _cache_38579728
    try:
        _cache_38579728 = True
    except:
        rcontext.setdefault('__error__', []).append((u'True', 9, 39, '<string>', _sys.exc_info()[1], ))
        raise

    _cache_38579728 = not _cache_38579728
    _backup_attrs_37107904 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24ca9d0> name=None at 24ca490> -> _value
    _value = _static_38578640
    econtext['attrs'] = _value
    _condition = _cache_38579728
    if _condition:

        # <div ... (9:4)
        # --------------------------------------------------------
        append(u'<div')
        _attr_class = u'omitted'
        if (_attr_class is not None):
            append((u' class="%s"' % _attr_class))
        append(u'>')
    _content_139955154988272 = u'Hello world!'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _condition = _cache_38579728
    if _condition:
        append(u'</div>')
    if (_backup_attrs_37107904 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_37107904
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)

    # <Negate value=<Expression u'True' (10:44)> at 24a5f90> -> _cache_38428560

    # <Expression u'True' (10:44)> -> _cache_38428560
    try:
        _cache_38428560 = True
    except:
        rcontext.setdefault('__error__', []).append((u'True', 10, 44, '<string>', _sys.exc_info()[1], ))
        raise

    _cache_38428560 = not _cache_38428560
    _backup_attrs_37108768 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24ca0d0> name=None at 24caad0> -> _value
    _value = _static_38576336
    econtext['attrs'] = _value
    _condition = _cache_38428560
    if _condition:

        # <div ... (10:4)
        # --------------------------------------------------------
        append(u'<div')
        _backup_default_36682712 = get('default', _marker)
        _value = u"${'omitted'}"
        econtext['default'] = _value

        # <Interpolation value=u"${'omitted'}" escape=True at 24ca050> -> _attr_class

        # <Expression u"'omitted'" (10:18)> -> _attr_class
        try:
            _attr_class = 'omitted'
        except:
            rcontext.setdefault('__error__', []).append((u"'omitted'", 10, 18, '<string>', _sys.exc_info()[1], ))
            raise

        _attr_class = _attr_class
        if (_attr_class is None):
            pass
        else:
            if (_attr_class is False):
                _attr_class = None
            else:
                _tt = type(_attr_class)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _attr_class = unicode(_attr_class)
                else:
                    try:
                        if (_tt is str):
                            _attr_class = decode(_attr_class)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _attr_class = _attr_class.__html__
                                except:
                                    _attr_class = convert(_attr_class)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _attr_class = _attr_class()
                    else:
                        if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                            if ('&' in _attr_class):
                                if (';' in _attr_class):
                                    _attr_class = re_amp.sub('&amp;', _attr_class)
                                else:
                                    _attr_class = _attr_class.replace('&', '&amp;')
                            if ('<' in _attr_class):
                                _attr_class = _attr_class.replace('<', '&lt;')
                            if ('>' in _attr_class):
                                _attr_class = _attr_class.replace('>', '&gt;')
                            if (u'"' in _attr_class):
                                _attr_class = _attr_class.replace(u'"', '&#34;')
        if (_attr_class is not None):
            append((u' class="%s"' % _attr_class))
        if (_backup_default_36682712 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_36682712
        append(u'>')
    _content_139955154988272 = u'Hello world!'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _condition = _cache_38428560
    if _condition:
        append(u'</div>')
    if (_backup_attrs_37108768 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_37108768
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_36649800 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36649800
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_38457568 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38457568
pass